@@ -1,18 +1,18 @@
 import click
 
 from asmrmanager.cli.core import rj_argument
-from asmrmanager.common.rj_parse import RJID
+from asmrmanager.common.types import LocalSourceID
 from asmrmanager.logger import logger
 
 
 @click.command()
-@rj_argument
+@rj_argument("local")
 @click.option("-s", "--star", type=int, help="must be integer in [1, 5]")
 @click.option("-c", "--comment", type=str)
-def review(rj_id: RJID, star: int, comment: str):
-    """review an ASMR with star(1-5) and comment and add it to storage path"""
+def review(source_id: LocalSourceID, star: int, comment: str):
+    """review an ASMR with star(1-5), add comment and put it into storage path"""
     logger.info(
-        f"run command review with rj_id={rj_id}, star={star} comment={comment}"
+        f"run command review with rj_id={source_id}, star={star} comment={comment}"
     )
 
     from asmrmanager.cli.core import create_database, fm
@@ -25,7 +25,7 @@ def review(rj_id: RJID, star: int, comment: str):
             "storage/download path not found skip storing operation"
         )
     else:
-        fm.store(rj_id)
+        fm.store(source_id)
         update_stored = True
-    db.update_review(rj_id, star, comment, update_stored=update_stored)
+    db.update_review(source_id, star, comment, update_stored=update_stored)
     db.commit()
