@@ -1,10 +1,12 @@
 import uuid
 from dataclasses import dataclass
 from enum import Enum
-from typing import NewType
+from typing import NewType, TypedDict
 
-RJID = NewType("RJID", int)
-RJName = NewType("RJName", str)
+SourceID = NewType("SourceID", int)
+SourceName = NewType("SourceName", str)
+LocalSourceID = NewType("LocalSourceID", SourceID)
+RemoteSourceID = NewType("RemoteSourceID", SourceID)
 
 
 class PRIVACY(Enum):
@@ -20,7 +22,7 @@ class PlayListItem:
     privacy: PRIVACY
     desc: str
     works_count: int
-    latest_work_id: RJID | None = None
+    latest_work_id: SourceID | None = None
 
     def asdict(self):
         return {
@@ -31,3 +33,9 @@ class PlayListItem:
             "works_count": self.works_count,
             "latest_work_id": self.latest_work_id,
         }
+
+
+class RecoverRecord(TypedDict):
+    path: str
+    url: str
+    should_download: bool
