@@ -1,5 +1,6 @@
 from datetime import datetime, timedelta
 from pathlib import Path
+from asmrmanager.logger import logger
 
 import click
 
@@ -16,7 +17,7 @@ def format_time(time):
 DEFAULT_THRESHOLD = timedelta(seconds=2)
 
 
-def vtt2lrc(vtt, header=True, threshold=DEFAULT_THRESHOLD):
+def vtt2lrc(vtt_path: Path, header=True, threshold=DEFAULT_THRESHOLD):
     lrc = ""
 
     if header:
@@ -24,15 +25,27 @@ def vtt2lrc(vtt, header=True, threshold=DEFAULT_THRESHOLD):
 
     last_end = parse_time("23:59:59.99")  # Insanely big value
 
+    vtt = vtt_path.read_text(encoding="utf-8")
     for chunk in vtt.split("\n\n")[1:]:
         if not chunk:
             continue
 
-        res = chunk.strip().split("\n", 1)
-        if res[0].isdigit():
-            time, text = res[1].split("\n", 1)
-        else:
-            time, text = res
+        # res = chunk.strip().split("\n", 1)
+        # if res[0].isdigit():
+        #     time, text = res[1].split("\n", 1)
+        # else:
+        #     time, text = res
+
+        match chunk.strip().split("\n"):
+            case [index, time, *text] if index.isdigit() and "-->" in time:
+                text = "\n".join(text)
+            case [time, *text] if "-->" in time:
+                text = "\n".join(text)
+            case _:
+                logger.warning(
+                    f"Invalid chunk in vtt file {vtt_path}:\n{chunk}"
+                )
+                continue
 
         begin, end = map(parse_time, time.split("-->"))
 
@@ -53,8 +66,7 @@ def vtt2lrc(vtt, header=True, threshold=DEFAULT_THRESHOLD):
     "vtt", type=click.Path(exists=True, dir_okay=False, path_type=Path)
 )
 def main(vtt: Path):
-    content = vtt.read_text(encoding="utf-8")
-    lrc = vtt2lrc(content)
+    lrc = vtt2lrc(vtt)
     with open(
         vtt.with_suffix("").with_suffix(".lrc"), "w", encoding="utf-8"
     ) as f:
