@@ -1,15 +1,14 @@
 import json
 from pathlib import Path
+from typing import Any
 
 import aioaria2
 
-from asmrmanager.logger import logger
-
 
 class Aria2Downloader:
     def __init__(
         self,
-        proxy: str,
+        proxy: str | None,
     ) -> None:
         self.client: aioaria2.Aria2HttpClient
         # logger.info(f"Connecting to aria2 rpc server: {self.client}")
@@ -19,10 +18,11 @@ class Aria2Downloader:
         #     {"all-proxy": proxy}
         # )
         # self.options.auto_file_renaming = False
-        self.options = {
-            "all-proxy": proxy,
+        self.options: dict[str, Any] = {
             "auto-file-renaming": False,
         }
+        if proxy:
+            self.options["all-proxy"] = proxy
 
     async def create_client(self, host: str, port: int, secret: str) -> None:
         self.client = await aioaria2.Aria2HttpClient(
